@@ -3,9 +3,9 @@
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.postgresql_psycopg2',
-        'NAME': 'integrado',
-        'USER': 'integrado',
-        'PASSWORD': 'integrado',
+        'NAME': 'lojaintegrada',
+        'USER': 'lojaintegrada',
+        'PASSWORD': 'lojaintegrada',
         'HOST': 'localhost',
         'PORT': '5432',
     }
@@ -16,4 +16,16 @@ DEBUG = True
 CHAVE_API = '55a4598f-800f-403f-ad56-aedbb35b90c6'
 CHAVE_APLICACAO = '7a7134e1-dfc3-4922-b145-eb8b605171aa'
 
+
+INSTALLED_APPS = (
+    'repositories',
+    'repositories.catalogo',
+    'repositories.cliente',
+    'repositories.cobranca',
+    'repositories.configuracao',
+    'repositories.faturamento',
+    'repositories.marketplace',
+    'repositories.pedido',
+    'repositories.plataforma',
+)
 # PAGADOR_CONF_PATH = "/home/marcioduarte/projects/lojaintegrada/pagador_config.conf"
\ No newline at end of file
