@@ -10,6 +10,8 @@ if hasattr(settings, "PAGADOR_CONF_PATH") and settings.PAGADOR_CONF_PATH is not
 
 config = Config.load(config_path)
 
+MEDIA_URL = config.MEDIA_URL
+
 DEBUG = config.DEBUG
 
 LIBS_MEIOS_DE_PAGAMENTO = config.LIBS_MEIOS_DE_PAGAMENTO
@@ -20,5 +22,5 @@ EVIDENCIA_URL = config.EVIDENCIA_URL
 
 MODULO_PARAMETROS_INSTALACAO = config.MODULO_PARAMETROS_INSTALACAO
 
-MERCADO_PAGO_REDIRECT_URL = config.MERCADO_PAGO_REDIRECT_URL
-MERCADO_PAGO_PREFERENCE_NOTIFICATION_URL = config.MERCADO_PAGO_PREFERENCE_NOTIFICATION_URL
\ No newline at end of file
+MERCADOPAGO_REDIRECT_URL = config.MERCADOPAGO_REDIRECT_URL
+MERCADOPAGO_PREFERENCE_NOTIFICATION_URL = config.MERCADOPAGO_PREFERENCE_NOTIFICATION_URL
\ No newline at end of file
